@@ -1043,6 +1043,7 @@ struct http_response* send_request(FILE* client, FILE* server, struct http_reque
       if (!strcasecmp(r->h.v1[i],"Host")) continue;
       if (!strcasecmp(r->h.v1[i],"Range")) continue;
       if (!strcasecmp(r->h.v1[i],"Connection")) continue;
+      if (!strcasecmp(r->h.v1[i],"Keep-Alive")) continue;
       if (!strncasecmp(r->h.v1[i],"Proxy-",6)) continue;
       if (!strcasecmp(r->h.v1[i],"Accept-Encoding")) continue;
       if (!strcasecmp(r->h.v1[i],"Content-Length")) continue;
@@ -1135,6 +1136,7 @@ struct http_response* send_request(FILE* client, FILE* server, struct http_reque
     }
 
     if (!strcasecmp(line,"Connection")) continue;
+    if (!strcasecmp(line,"Keep-Alive")) continue;
     if (!strcasecmp(line,"Content-Range")) continue;
 
     if (!strcasecmp(line,"Content-Type")) {
